#[non_exhaustive]pub enum Base58Error {
BufferTooSmall,
DecodeFailed,
InvalidCharacter,
NonAsciiCharacter,
InputTooLarge,
}Expand description
Error returned when base58btc decoding fails.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BufferTooSmall
The output buffer was too small to hold the decoded bytes.
DecodeFailed
Decoding failed for a reason not covered by the other variants.
InvalidCharacter
The input contained a character outside the base58btc alphabet.
NonAsciiCharacter
The input contained a non-ASCII character.
InputTooLarge
The input exceeded the accepted base58btc text length.