#[non_exhaustive]pub enum MultibaseError {
InputTooLarge,
TooShort,
UnsupportedPrefix,
Base58(Base58Error),
Base64Url,
LengthOverflow,
}Expand description
Error returned when decoding a multibase string fails.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InputTooLarge
Encoded multibase text exceeded the supported resource limit.
TooShort
The input is too short to contain a multibase prefix and payload.
UnsupportedPrefix
The leading multibase prefix denotes an unsupported base encoding.
Base58(Base58Error)
The base58btc payload failed to decode.
Base64Url
The base64url payload failed to decode.
LengthOverflow
The encoded output length would exceed the supported allocation domain.